# [WBML](https://github.com/wesselb/wbml)

[![CI](https://github.com/wesselb/wbml/workflows/CI/badge.svg?branch=master)](https://github.com/wesselb/wbml/actions?query=workflow%3ACI)
[![Coverage Status](https://coveralls.io/repos/github/wesselb/wbml/badge.svg?branch=master&service=github)](https://coveralls.io/github/wesselb/wbml?branch=master)
[![Latest Docs](https://img.shields.io/badge/docs-latest-blue.svg)](https://wesselb.github.io/wbml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Machine learning stuff

## Requirements and Installation

See [the instructions here](https://gist.github.com/wesselb/4b44bf87f3789425f96e26c4308d0adc).
Then simply

```
pip install wbml
```